@@ -6,20 +6,11 @@ from time import time
 import logging
 from tempfile import TemporaryFile
 from psutil import virtual_memory
-from scipy.ndimage.filters import gaussian_filter
 from tqdm import tqdm
-from scipy.stats import pearsonr
 from operator import itemgetter
-from scipy.ndimage.interpolation import zoom
 import numpy as np
 from numba import jit
 
-try:
-    from sklearn.model_selection import train_test_split
-except ImportError:
-    # old depreciated version
-    from sklearn.cross_validation import train_test_split
-
 
 def __zeros__(shape, dtype, max_mem_frac=0.3, logger=None):
     logger = logger or logging.getLogger(__name__)
@@ -285,6 +276,8 @@ def __test__(clf, xx, yy, sample_weight=None, norm="right_class"):
                                norm value is the normalized mean class distance
     :return: if sample weight is None: value between 0 and 1, one is best
     """
+    from scipy.stats import pearsonr  # import here to avoid static TLS ImportError
+
     if norm == "right_class":
         if sample_weight is None:
             return np.sum(clf.predict(xx) == yy) / np.float(len(yy))  # ratio of correct
@@ -380,6 +373,10 @@ class ClassicalBayesian(object):
         ids[ids > self.n_bins - 1] = self.n_bins - 1
 
     def __predict__(self, xx):
+        # import here to avoid static TLS ImportError
+        from scipy.ndimage.interpolation import zoom
+        from scipy.ndimage.filters import gaussian_filter
+
         ids = [digitize(ff, bb) - 1 for ff, bb in zip(self.mk_clf(xx).transpose(), self.bb_full)]
         tt = 0
         for ii in ids:
@@ -560,6 +557,8 @@ class ClassicalBayesianFit(ClassicalBayesian):
             return self
 
     def mk_hist(self, xx):
+        from scipy.ndimage.filters import gaussian_filter  # import here to avoid static TLS ImportError
+
         hh = histogramdd_fast(xx, self.bns)
         if self.smooth is not None:
             hh = gaussian_filter(hh, self.smooth)
@@ -578,6 +577,7 @@ class ClassicalBayesianFit(ClassicalBayesian):
         return np.interp(xxx, np.hstack((np.array([0]), cdf)), bins)
 
     def set(self, xx, yy, smooth=None, n_bins=5, sample_weight=None):
+        from sklearn.model_selection import train_test_split  # import here to avoid static TLS ImportError
 
         self.sample_weight = sample_weight
         self.n_bins = n_bins
@@ -723,6 +723,7 @@ class ClassicalBayesianFit(ClassicalBayesian):
         self.max_run_time = max_run_time
 
     def fit_random(self, xx, yy, sample_weight=None, test_size=None, sufficient_norm=None, return_opts=False):
+        from sklearn.model_selection import train_test_split  # import here to avoid static TLS ImportError
 
         if sample_weight is not None:
             xx_train, xx_test, yy_train, yy_test, sw_train, sw_test = train_test_split(xx, yy, sample_weight,
