@@ -24,9 +24,6 @@ from PIL import Image
 from gdalconst import GA_ReadOnly
 from geoarray import GeoArray
 from psutil import virtual_memory
-from scipy.interpolate import bisplev
-from scipy.interpolate import bisplrep
-from scipy.ndimage.interpolation import zoom
 
 from ...RSImage import RSImage
 from ..GranuleInfo import GranuleInfo
@@ -34,6 +31,8 @@ from ..GranuleInfo import GranuleInfo
 
 def get_tck(x, y, z, kk_default=3, logger=None):
     """Estimate spline model parameters."""
+    from scipy.interpolate import bisplrep  # import here to avoid static TLS ImportError
+
     logger = logger or logging.getLogger(__name__)
     # estimate max number of allowed spline order
     mm = len(x)
@@ -81,6 +80,9 @@ class S2Image(RSImage):
         ..todo:: Real nodata mask
 
         """
+        # import here to avoid static TLS ImportError
+        from scipy.interpolate import bisplev
+        from scipy.ndimage.interpolation import zoom
 
         t0_init = time()
 
